ApiConstants class

Constructors

ApiConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

agentAvailability String
getter/setter pair
agentRms String
getter/setter pair
baseUrl String
getter/setter pair
initiateAddressVerification String
getter/setter pair
initiateVerification String
getter/setter pair
resendOtp String
getter/setter pair
scheduleAppointment String
getter/setter pair
schedulingBaseUrl String
getter/setter pair
verifyAddress String
getter/setter pair
verifyDocument String
getter/setter pair
verifyLiveliness String
getter/setter pair
verifyOtp String
getter/setter pair