ApiService class

Constructors

ApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAgentAvailability(String agentId, String timezone) Future<Response>
getAgentRms(String agentId) Future<Response>
initiateVerification(String apiKey, String email, String phone, String firstName, String lastName, String address, String business, String verificationType, bool isAddressCheck, bool isAmlCheck, bool isCreditCheck, bool isOtpRequired, String idType, String idNumber, String addressCheckType) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resendOtp(String id, String apiKey) Future<Response>
scheduleAppointment({required String agentId, required String customerName, required String customerEmail, required String customerPhone, required String accountNumber, required String date, required String startDatetime, required String endDatetime, String timezone = '', String agentName = '', String agentEmail = '', String agentCode = '', String agentBranchCode = '', String agentBankName = '', String agentBankCode = '', String amount = '', String currency = 'Cedis'}) Future<Response>
toString() String
A string representation of this object.
inherited
validateOtp(String id, String otp, String apiKey) Future<Response>
verifyAddress({required String apiKey, required String id, required String country, required String nationality, required String address, required String addressCheckType, required List<String> selfieInHouse, required List<String> picturesOfHouse, required List<String> proofOfResidence, double? latitude, double? longitude, String? scheduledDate, String? scheduledTime}) Future<Response>
verifyCard(String apiKey, String id, String cardFront, String cardBack, String selfie) Future<Response>
verifyLiveliness(String apiKey, String id, String cardFront, String selfie) Future<Response>

Operators

operator ==(Object other) bool
The equality operator.
inherited