ImagePickerUtilMultiple class

Constructors

ImagePickerUtilMultiple()

Properties

base64ImageLists Map<String, List<String>?>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageLists Map<String, List<File>?>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCameraImages(String key, List<File> images) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickImages(String key, ImageSource source, BuildContext context) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited